@@ -17,17 +17,6 @@ from datetime import datetime
 class MultiValueDict(object):
     pass
 
-@contextlib.contextmanager
-def pprint_OrderedDict():
-    pp_orig = pprint._sorted
-    od_orig = OrderedDict.__repr__
-    try:
-        pprint._sorted = lambda x:x
-        OrderedDict.__repr__ = dict.__repr__
-        yield
-    finally:
-        pprint._sorted = pp_orig
-        OrderedDict.__repr__ = od_orig
 
 @contextlib.contextmanager
 def pprint_ordered():
@@ -543,8 +532,7 @@ Returns:
 
     # ordered dict -> show as json would?
     if ignore_builtin and isinstance(obj, OrderedDict):
-        with pprint_OrderedDict():
-            pprint.pprint(obj, indent=2, width=2)
+        pprint.pprint(obj, indent=2, width=2, sort_dicts=False)
         return
 
     # TODO: print members of a module
@@ -638,20 +626,20 @@ Returns:
                         item_id, datas = _print_minimal_values(row, values, additional=callable_value, truncate=truncate)
                         widths = [lenesc(x) for x in datas]
                         col_max = [max(x) for x in zip(col_max, widths)]
-                        lines.append(('{:6}'.format(item_id), datas))
+                        lines.append(('{:6}'.format(str(item_id)), datas))
                 elif callables:
                     for row, row_object in zip(page.values('pk', *values), page):
                         values_callable = [(call, get_callable_value(row_object, call)) for call in callables]
                         item_id, datas = _print_minimal_values(row, values, additional=values_callable, truncate=truncate)
                         widths = [lenesc(x) for x in datas]
                         col_max = [max(x) for x in zip(col_max, widths)]
-                        lines.append(('{:6}'.format(item_id), datas))
+                        lines.append(('{:6}'.format(str(item_id)), datas))
                 else:
                     for row in page.values('pk', *values):
                         item_id, datas = _print_minimal_values(row, values, truncate=truncate)
                         widths = [lenesc(x) for x in datas]
                         col_max = [max(x) for x in zip(col_max, widths)]
-                        lines.append(('{:6}'.format(item_id), datas))
+                        lines.append(('{:6}'.format(str(item_id)), datas))
 
                 #print ''.join( v, w in zip(values, col_max) )
 
@@ -679,7 +667,7 @@ Returns:
                 if done < total:
                     try:
                         while True:
-                            userinput = input("-- {} ({}) / {} ({}) -- ".format(done, done//results_per_page, total, int(ceil(total/float(results_per_page)))))
+                            userinput = input("-- {} ({}) / {} ({}) -- ".format(done, int(done//results_per_page), total, int(ceil(total/float(results_per_page)))))
                             if userinput.startswith('q'):
                                 pagenum = -1
                                 break
@@ -730,7 +718,7 @@ Returns:
                 if done < total:
                     try:
                         while True:
-                            userinput = input("-- {} ({}) / {} ({}) -- ".format(done, done/results_per_page, total, int(ceil(total/float(results_per_page)))))
+                            userinput = input("-- {} ({}) / {} ({}) -- ".format(done, int(done/results_per_page), total, int(ceil(total/float(results_per_page)))))
                             if userinput.startswith('q'):
                                 pagenum = -1
                                 break
@@ -790,6 +778,10 @@ def paginateQuerySet(queryset, pagerowcount, autosense=True, disable=False):
         return
     # print "paginating {}/{}".format(total, pagerowcount)
 
+    # set explicit order_by id if not specified (to silence warning)
+    if not queryset.ordered:
+        queryset = queryset.order_by('id')
+
     paginator = Paginator(queryset, pagerowcount)
     total = paginator.count # excecute query
     # autosense paginates only when output is more than 2.5 x screen size
@@ -1269,7 +1261,7 @@ def _print_orm(obj, ignore_builtin=True, values_only=False, padding=0, color=Tru
 
     # print object identifier
     if stream is not None:
-        stream.write( ("{} : {}\n".format(uni(obj), type(obj))).encode('utf-8') )
+        stream.write( ("{} : {}\n".format(uni(obj), type(obj))) )
     else:
         print_asc("{} : {}".format(uni(obj), type(obj)))
 
